==> icons-vue-0.2.8.tgz: package/lib/user--favorite/32.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_UserFavorite32 = {
  name: 'UserFavorite32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M27.303 12a2.6724 2.6724 0 0 0-1.9079.7994l-.3932.4022-.397-.4022a2.6763 2.6763 0 0 0-3.8157 0 2.7612 2.7612 0 0 0 0 3.8655l4.2127 4.2637 4.2089-4.2637a2.7612 2.7612 0 0 0 0-3.8655A2.6723 2.6723 0 0 0 27.303 12zM2 30H4V25a5.0059 5.0059 0 0 1 5-5h6a5.0059 5.0059 0 0 1 5 5v5h2V25a7.0082 7.0082 0 0 0-7-7H9a7.0082 7.0082 0 0 0-7 7zM12 4A5 5 0 1 1 7 9a5 5 0 0 1 5-5m0-2a7 7 0 1 0 7 7A7 7 0 0 0 12 2z"
      }
    }), children]);
  }
};

module.exports = virtual_UserFavorite32;

==> icons-vue-0.3.0.tgz: package/lib/user--favorite/32.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_UserFavorite32 = {
  name: 'UserFavorite32',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '32',
      height: '32',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = __chunk_1._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M27.303 12a2.6616 2.6616 0 0 0-1.9079.8058l-.3932.4054-.397-.4054a2.6615 2.6615 0 0 0-3.8157 0 2.7992 2.7992 0 0 0 0 3.8964L25.0019 21l4.2089-4.2978a2.7992 2.7992 0 0 0 0-3.8964A2.6616 2.6616 0 0 0 27.303 12zM2 30H4V25a5.0059 5.0059 0 0 1 5-5h6a5.0059 5.0059 0 0 1 5 5v5h2V25a7.0082 7.0082 0 0 0-7-7H9a7.0082 7.0082 0 0 0-7 7zM12 4A5 5 0 1 1 7 9a5 5 0 0 1 5-5m0-2a7 7 0 1 0 7 7A7 7 0 0 0 12 2z"
      }
    }), children]);
  }
};

module.exports = virtual_UserFavorite32;
